%bcond_with reconf

%define admin_trust_dir %{_sysconfdir}/pki/trust
%define package_trust_dir %{_datadir}/pki/trust

Name: p11-kit
Version: 0.23.14
Release: 1
License: BSD-3-Clause
Summary: p11-kit
Url: https://p11-glue.freedesktop.org/p11-kit.html

Source0: https://github.com/p11-glue/p11-kit/releases/download/%{version}/p11-kit-%{version}.tar.gz

Patch0: pll-kit-getprogname-aix.patch
Patch1: p11-kit-gcc-bug-workaround.patch
Patch2: p11-kit-no-getpeereid.patch

Requires: libp11-kit0 = %{version}

BuildRequires: pkg-config 
BuildRequires: libtasn1-devel
BuildRequires: libutil-devel
BuildRequires: libffi-devel

%description
Provides a way to load and enumerate PKCS#11 modules. Provides a standard
configuration setup for installing PKCS#11 modules in such a way that they're
discoverable. Also solves problems with coordinating the use of PKCS#11 by
different components or libraries living in the same process.

%package -n libp11-kit0
Summary: p11-kit library

%description -n libp11-kit0
Provides a way to load and enumerate PKCS#11 modules. Provides a standard
configuration setup for installing PKCS#11 modules in such a way that they're
discoverable. Also solves problems with coordinating the use of PKCS#11 by
different components or libraries living in the same process.

%package trust
Summary: p11-kit trust policy module

%description trust
The trust module provides system certificate anchors, blacklists and other trust
policy to crypto libraries applications. This information is exposed as PKCS#11
objects.

You can use the trust command line tool to examine and modify the trust policy
store.


%package devel
Summary: p11-kit development headers
Requires: libp11-kit0 = %{version}

%description devel
p11-kit headers and development libraries

%prep
%setup -q

%patch0 -p1
%patch1 -p1
%patch2 -p1

%build

%if %{with reconf}
autoreconf -fi
%else
%define _host powerpc64-ibm-aix6
%endif

# Note: p11-kit expects malloc(0) to return a valid pointer
# thus we define _LINUX_SOURCE_COMPAT

%configure \
  ac_cv_func_getpeereid=no \
  CPPFLAGS='-pthread -D_LINUX_SOURCE_COMPAT' \
  LDFLAGS="-pthread -Wl,-blibpath:%{_libdir}:/QOpenSys/usr/lib" \
  LIBS='-lutil' \
  --with-libtasn1 \
  --with-libffi \
  --with-trust-paths=%{admin_trust_dir}:%{package_trust_dir} \
  --with-aix-soname=svr4 \
  --without-systemd \
  --disable-doc \
  --disable-nls \
  --disable-rpath \
  --disable-static

%make_build

# make check

%install

%make_install

rm -r %{buildroot}/%{_datadir}/gtk-doc

find %{buildroot}%{_libdir} -name \*.la | xargs rm

mkdir -p %{buildroot}%{admin_trust_dir}/anchors
mkdir -p %{buildroot}%{admin_trust_dir}/blacklist

mkdir -p %{buildroot}%{package_trust_dir}/anchors
mkdir -p %{buildroot}%{package_trust_dir}/blacklist


rm %{buildroot}%{_sysconfdir}/pkcs11/pkcs11.conf.example

# These are plugins, which should not be linked to, but loaded dynamically
# thus they should be shared objects not archives. We set them to load-only
# with strip -e to prevent applications linking directly to them
function extract_shared_obj
{
    ar -X64 x $1
    strip -e shr_64.o
    mv shr_64.o $1
    rm shr_64.imp
}

extract_shared_obj %{buildroot}%{_libdir}/p11-kit-proxy.so
extract_shared_obj %{buildroot}%{_libdir}/pkcs11/p11-kit-trust.so

# the p11-kit-server doesn't work due to needing getpeereid, for now
# we just disable both the client and server. Conceivably, we could
# ship the client and have the server be somewhere else, but we'd
# want to investigate further wether this actually works and if that
# is something users would want.
# extract_shared_obj %{buildroot}%{_libdir}/pkcs11/p11-kit-client.so
rm %{buildroot}%{_libdir}/pkcs11/p11-kit-client.so
rm %{buildroot}%{_libexecdir}/p11-kit/p11-kit-remote

rm %{buildroot}%{_libexecdir}/p11-kit/p11-kit-server

%files
%defattr(-, qsys, *none)
%{_bindir}/p11-kit

%doc p11-kit/pkcs11.conf.example.in

%{_datadir}/p11-kit
%exclude %{_datadir}/p11-kit/modules/*.module

%dir %{_libdir}/pkcs11

%{admin_trust_dir}
%{package_trust_dir}

%files trust
%defattr(-, qsys, *none)
%{_bindir}/trust

%{_libdir}/pkcs11/p11-kit-trust.so

%{_libexecdir}/p11-kit/trust-extract-compat

%{_datadir}/p11-kit/modules/p11-kit-trust.module


%files -n libp11-kit0
%defattr(-, qsys, *none)

%{_libdir}/libp11-kit.so.*

%{_libdir}/p11-kit-proxy.so


%files devel
%defattr(-, qsys, *none)
%{_libdir}/libp11-kit.so

%{_includedir}/p11-kit-1

%{_libdir}/pkgconfig/p11-kit-1.pc


%changelog

* Fri Mar 22 2019 Kevin Adler <kadler@us.ibm.com>
- split trust module in to separate package
- add _LINUX_SOURCE_COMPAT for malloc(0)
- disable & remove server module due to missing getpeereid
- general cleanup

* Thu Mar 07 2019 - MO JI <jimo@cn.ibm.com>
- Update to 0.23.14

* Wed Nov 22 2017 - Kevin Adler <kadler@us.ibm.com>
- Update BuildRequires for packages

* Tue Nov 21 2017 - Kevin Adler <kadler@us.ibm.com>
- Remove unneeded Provides in p11-kit

* Tue Nov 21 2017 - Kevin Adler <kadler@us.ibm.com>
- Use automatic dependency generation

* Tue Nov 07 2017 - Kevin Adler <kadler@us.ibm.com>
- Fix licenses in spec files

* Fri Sep 15 2017 - Kevin Adler <kadler@us.ibm.com>
- convert to svr4-style shared libraries

* Mon Jun 05 2017 - Kevin Adler <kadler@us.ibm.com>
- Use make_build and make_install macros

* Sun Apr 23 2017 - Kevin Adler <kadler@us.ibm.com>
- Remove extra space in Summary lines

* Thu Apr 20 2017 - Kevin Adler <kadler@us.ibm.com>
- Add spec files
